@@ -1,5 +1,6 @@
 import requests
 import time
+from bryson.utils.welcome import print_welcome
 
 def getBTCHash():
     '''
@@ -65,4 +66,6 @@ def getRNG(btcHash,ethHash):
     return (btcNum/ethNum) * time.time()
 
 def random():
-    return getRNG(getBTCHash(),getETHHash())
\ No newline at end of file
+    return getRNG(getBTCHash(),getETHHash())
+
+print_welcome()
\ No newline at end of file
